@@ -71,7 +71,7 @@ ProjectCMap <- function(main_path, project_name, coder = "qcoder", sep = ">"){
 ##' 
 ##' @param project A QDA project, a list as generated by the ProjectCMap function.
 ##' @inheritParams ProjectCMap
-##' @return A data.frame with the relationships identified in the interviews. Each relationships is linked to an agent ('name'), an edge's name ('edge') and a simplified edge's name ('edge.a') where any extra character other than "INTERGER>INTEGER" have been removed and the separator string has been replaced with "~", the varible at the origin of the relationships ('from'), the variable at the end of the relationships ('to').
+##' @return A data.frame with the relationships identified in the interviews. Each relationships ('coding_id') is linked to an agent ('doc_ed'), an edge's name ('edge'), the varible at the origin of the relationships ('concept_from'), the variable at the end of the relationships ('concept_to'), other properties of the relationships ('coding_sign', 'coding_weight', 'coding_class' and 'document_part') and the quotes linked to relationships ('selected_text').
 ##' @examples
 ##' project_name <- "a_new_project"
 ##' main_path <- paste0(system.file("testdata", package = "cogmapr"), '/')
@@ -81,22 +81,12 @@ ProjectCMap <- function(main_path, project_name, coder = "qcoder", sep = ">"){
 ##' @export 
 
 EdgCMap <- function(project, sep = ">", coder = "qcoder") {
-    if (coder == "RQDA") {
-        db.con <- DBI::dbConnect(drv=dbDriver("SQLite"),project)
-        data.edges <- DBI::dbGetQuery(db.con,paste("SELECT source.name, freecode.name FROM coding JOIN source ON coding.fid = source.id JOIN freecode ON coding.cid = freecode.id WHERE freecode.name LIKE '%",sep,"%' AND coding.status='1'",sep=""))
-        names(data.edges)[1:2] <- c("name","edge")[1:2]
-        data.edges$edge <- gsub(sep,"~",gsub(paste("(\\D*)(\\d+",sep,"\\d+)(\\D*)",sep=""),"\\2",data.edges$edge))
-        data.edges$from <- gsub("(\\d+)~(\\d+)","\\1",data.edges$edge)
-        data.edges$to <- gsub("(\\d+)~(\\d+)","\\2",data.edges$edge)
-    }
-    else if (coder == "qcoder") {
+    if (coder == "qcoder") {
         data.edges <- project[['codings']] %>%
             dplyr::mutate(edge = paste(concept_from, concept_to, sep="~"))
     } else {return(warning("coder not known, sorry!"))}
     ## class(data.edges) <- "EdgCMap"
-
     return(data.edges)
-
 }
 
 
